==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/poshuku/plugins/fua/leechcraft_poshuku_fua_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>Changer</name>
    <message>
        <location filename="changer.ui" line="14"/>
        <source>Fake user agent</source>
        <translation>Agente de usuario falso</translation>
    </message>
    <message>
        <location filename="changer.ui" line="25"/>
        <source>Domain:</source>
        <translation>Dominio:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="35"/>
        <source>Agent:</source>
        <translation>Agente:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="45"/>
        <source>ID string:</source>
        <translation>Cadena ID:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="57"/>
        <source>%Platform% and %Subplatform% are expanded to the windowing system and the operation system.
%Security% is expanded to U if SSL is enabled, otherwise N.
%Locale% is replaced with current locale name.
%WebKitVersion% is expanded to WebKit version.
%AppVersion% is expanded to the application&apos;s version.</source>
        <translation>%Platform% y %Subplatform% se expanden por el sistema de ventanas y el sistema operativo.
%Security% se expande a U si el SSL está activado, en otro caso N.
%Locale% se reemplaza con el nombre local actual.
%WebKitVersion% se expande a la versión de WebKit.
%AppVersion% se expande a la versión de la aplicación.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::Fua::FUA</name>
    <message>
        <location filename="fua.cpp" line="60"/>
        <source>Domain</source>
        <translation>Dominio</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="61"/>
        <source>Agent</source>
        <translation>Agente</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="62"/>
        <source>Identification string</source>
        <translation>Cadena de identificación</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="101"/>
        <source>Allows to set fake user agents for different sites.</source>
        <translation>Permite asignar agentes de usuarios falsos para diferentes sitios.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="settings.ui" line="27"/>
        <source>Add...</source>
        <translation>Añadir...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="34"/>
        <source>Modify...</source>
        <translation>Modificar...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>Remove</source>
        <translation>Quitar</translation>
    </message>
    <message>
        <location filename="settings.ui" line="65"/>
        <source>Changes would be applied immediately</source>
        <translation>Los cambios serán aplicados imediatamente</translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.65.tar.bz2: leechcraft-0.4.65/src/plugins/poshuku/plugins/fua/leechcraft_poshuku_fua_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="es">
<context>
    <name>Changer</name>
    <message>
        <location filename="changer.ui" line="14"/>
        <source>Fake user agent</source>
        <translation>Agente de usuario falso</translation>
    </message>
    <message>
        <location filename="changer.ui" line="25"/>
        <source>Domain:</source>
        <translation>Dominio:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="35"/>
        <source>Agent:</source>
        <translation>Agente:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="45"/>
        <source>ID string:</source>
        <translation>Cadena ID:</translation>
    </message>
    <message>
        <location filename="changer.ui" line="57"/>
        <source>%Platform% and %Subplatform% are expanded to the windowing system and the operation system.
%Security% is expanded to U if SSL is enabled, otherwise N.
%Locale% is replaced with current locale name.
%WebKitVersion% is expanded to WebKit version.
%AppVersion% is expanded to the application&apos;s version.</source>
        <translation>%Platform% y %Subplatform% se expanden por el sistema de ventanas y el sistema operativo.
%Security% se expande a U si el SSL está activado, en otro caso N.
%Locale% se reemplaza con el nombre local actual.
%WebKitVersion% se expande a la versión de WebKit.
%AppVersion% se expande a la versión de la aplicación.</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Poshuku::Plugins::Fua::FUA</name>
    <message>
        <location filename="fua.cpp" line="70"/>
        <source>Domain</source>
        <translation>Dominio</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="71"/>
        <source>Agent</source>
        <translation>Agente</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="72"/>
        <source>Identification string</source>
        <translation>Cadena de identificación</translation>
    </message>
    <message>
        <location filename="fua.cpp" line="116"/>
        <source>Allows to set fake user agents for different sites.</source>
        <translation>Permite asignar agentes de usuarios falsos para diferentes sitios.</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="settings.ui" line="27"/>
        <source>Add...</source>
        <translation>Añadir...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="34"/>
        <source>Modify...</source>
        <translation>Modificar...</translation>
    </message>
    <message>
        <location filename="settings.ui" line="41"/>
        <source>Remove</source>
        <translation>Quitar</translation>
    </message>
    <message>
        <location filename="settings.ui" line="65"/>
        <source>Changes would be applied immediately</source>
        <translation>Los cambios serán aplicados imediatamente</translation>
    </message>
</context>
<context>
    <name>poshukufuasettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>FUA settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
